@@ -20,6 +20,7 @@ from os_win.utils.winapi import wintypes
 # winerror.h
 ERROR_INVALID_HANDLE = 6
 ERROR_NOT_READY = 21
+ERROR_SHARING_VIOLATION = 32
 ERROR_SHARING_PAUSED = 70
 ERROR_INSUFFICIENT_BUFFER = 122
 ERROR_DIR_IS_NOT_EMPTY = 145
@@ -329,3 +330,5 @@ GET_VIRTUAL_DISK_INFO_PROVIDER_SUBTYPE = 7
 GET_VIRTUAL_DISK_INFO_IS_LOADED = 13
 
 SET_VIRTUAL_DISK_INFO_PARENT_PATH = 1
+SET_VIRTUAL_DISK_INFO_IDENTIFIER = 2
+SET_VIRTUAL_DISK_INFO_VIRTUAL_DISK_ID = 5
