@@ -161,6 +161,7 @@ class _VHD_INFO(ctypes.Union):
         ("VirtualStorageType", VIRTUAL_STORAGE_TYPE),
         ("ProviderSubtype", wintypes.ULONG),
         ("Is4kAligned", wintypes.BOOL),
+        ("IsLoaded", wintypes.BOOL),
         ("PhysicalDisk", _VHD_INFO_PHYSICAL_DISK),
         ("VhdPhysicalSectorSize", wintypes.ULONG),
         ("SmallestSafeVirtualSize", wintypes.ULARGE_INTEGER),
@@ -179,11 +180,19 @@ class GET_VIRTUAL_DISK_INFO(ctypes.Structure):
 PGET_VIRTUAL_DISK_INFO = ctypes.POINTER(GET_VIRTUAL_DISK_INFO)
 
 
-# Only this version is used, we avoid defining a union.
+class _SET_VIRTUAL_DISK_INFO_U(ctypes.Union):
+    _fields_ = [
+        ('ParentFilePath', wintypes.LPCWSTR),
+        ('UniqueIdentifier', wintypes.GUID),
+        ('VirtualDiskId', wintypes.GUID),
+    ]
+
+
 class SET_VIRTUAL_DISK_INFO(ctypes.Structure):
+    _anonymous_ = ['_setinfo']
     _fields_ = [
         ('Version', wintypes.DWORD),
-        ('ParentFilePath', wintypes.LPCWSTR)
+        ('_setinfo', _SET_VIRTUAL_DISK_INFO_U)
     ]
 
 
